alac

package module
v0.0.0-...-3987f6f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 19, 2022 License: Apache-2.0 Imports: 2 Imported by: 0

README

ALAC (Apple LossLess Audio Codec)

A small golang wrapper around David Hammerton's alac decoder. To see more details on the original C implementation, please visit http://crazney.net/programs/itunes/alac.html. Apple also provides a C++ ALAC encoder/decoder as OSS. You can find that at http://alac.macosforge.org.

Forked from tongxingwy/alac

Installation

go get github.com/carterpeel/alac

License

Apache v2 License.

Contact

Austin Cherry

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type File

type File struct {
	// contains filtered or unexported fields
}

File is a wrapper type around the C type.

func New

func New(sampleSize, numberOfChannels int) File

New Allocates new AlacFile.

func (*File) AllocateBuffers

func (f *File) AllocateBuffers()

AllocateBuffers Allocates the C buffers for our AlacFile.

func (*File) DecodeFrame

func (f *File) DecodeFrame(inputBuffer []byte) []byte

DecodeFrame Decodes a frame from inputBuffer and puts it in the outputBuffer.

func (*File) Free

func (f *File) Free()

Free frees the C buffers we wrap in our AlacFile type.

func (*File) SetInfo

func (f *File) SetInfo(inputBuffer []byte)

SetInfo Set's the "info" for our AlacFile.

Jump to