package
module
Version:
v0.0.0-...-3987f6f
Opens a new window with list of versions in this module.
Published: Jan 19, 2022
License: Apache-2.0
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
ALAC (Apple LossLess Audio Codec)
A small golang wrapper around David Hammerton's alac decoder. To see more details on the original C implementation, please visit http://crazney.net/programs/itunes/alac.html. Apple also provides a C++ ALAC encoder/decoder as OSS. You can find that at http://alac.macosforge.org.
Forked from tongxingwy/alac
Installation
go get github.com/carterpeel/alac
License
Apache v2 License.
Austin Cherry
Documentation
¶
File is a wrapper type around the C type.
func New(sampleSize, numberOfChannels int) File
New Allocates new AlacFile.
func (f *File) AllocateBuffers()
AllocateBuffers Allocates the C buffers for our AlacFile.
DecodeFrame Decodes a frame from inputBuffer and puts it in the outputBuffer.
Free frees the C buffers we wrap in our AlacFile type.
func (f *File) SetInfo(inputBuffer []byte)
SetInfo Set's the "info" for our AlacFile.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.